==> arthur_client-1.4.1216.tar.gz: arthur_client-1.4.1216/arthur_client/api_bindings/docs/MetricsColumnParameterSchema.md <==
# MetricsColumnParameterSchema


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**parameter_key** | **str** | Name of the parameter. | 
**optional** | **bool** | Boolean denoting if the parameter is optional. | [optional] [default to False]
**friendly_name** | **str** | User facing name of the parameter. | 
**description** | **str** | Description of the parameter. | 
**tag_hints** | [**List[ScopeSchemaTag]**](ScopeSchemaTag.md) | List of tags that are applicable to this parameter. Datasets with columns that have matching tags can be inferred this way. | [optional] [default to []]
**source_dataset_parameter_key** | **str** | Name of the parameter that provides the dataset to be used for this column. | 
**allowed_column_types** | [**List[MetricsColumnListParameterSchemaAllowedColumnTypesInner]**](MetricsColumnListParameterSchemaAllowedColumnTypesInner.md) |  | [optional] 
**allow_any_column_type** | **bool** | Indicates if this metric parameter can accept any column type. | [optional] [default to False]
**parameter_type** | **str** |  | [optional] [default to 'column']

## Example

```python
from arthur_client.api_bindings.models.metrics_column_parameter_schema import MetricsColumnParameterSchema

# TODO update the JSON string below
json = "{}"
# create an instance of MetricsColumnParameterSchema from a JSON string
metrics_column_parameter_schema_instance = MetricsColumnParameterSchema.from_json(json)
# print the JSON string representation of the object
print(MetricsColumnParameterSchema.to_json())

# convert the object into a dict
metrics_column_parameter_schema_dict = metrics_column_parameter_schema_instance.to_dict()
# create an instance of MetricsColumnParameterSchema from a dict
metrics_column_parameter_schema_from_dict = MetricsColumnParameterSchema.from_dict(metrics_column_parameter_schema_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> arthur_client-1.4.1646.tar.gz: arthur_client-1.4.1646/arthur_client/api_bindings/docs/MetricsColumnParameterSchema.md <==
# MetricsColumnParameterSchema


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**parameter_key** | **str** | Name of the parameter. | 
**friendly_name** | **str** | User facing name of the parameter. | 
**description** | **str** | Description of the parameter. | 
**tag_hints** | [**List[ScopeSchemaTag]**](ScopeSchemaTag.md) | List of tags that are applicable to this parameter. Datasets with columns that have matching tags can be inferred this way. | [optional] [default to []]
**source_dataset_parameter_key** | **str** | Name of the parameter that provides the dataset to be used for this column. | 
**allowed_column_types** | [**List[BaseColumnParameterSchemaAllowedColumnTypesInner]**](BaseColumnParameterSchemaAllowedColumnTypesInner.md) |  | [optional] 
**allow_any_column_type** | **bool** | Indicates if this metric parameter can accept any column type. | [optional] [default to False]
**parameter_type** | **str** |  | [optional] [default to 'column']
**optional** | **bool** | Boolean denoting if the parameter is optional. | [optional] [default to False]

## Example

```python
from arthur_client.api_bindings.models.metrics_column_parameter_schema import MetricsColumnParameterSchema

# TODO update the JSON string below
json = "{}"
# create an instance of MetricsColumnParameterSchema from a JSON string
metrics_column_parameter_schema_instance = MetricsColumnParameterSchema.from_json(json)
# print the JSON string representation of the object
print(MetricsColumnParameterSchema.to_json())

# convert the object into a dict
metrics_column_parameter_schema_dict = metrics_column_parameter_schema_instance.to_dict()
# create an instance of MetricsColumnParameterSchema from a dict
metrics_column_parameter_schema_from_dict = MetricsColumnParameterSchema.from_dict(metrics_column_parameter_schema_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
